compare_ptrs

Function compare_ptrs 

pub unsafe fn compare_ptrs(
    fn_name: &str,
    afl_cmp_area: *mut u8,
    base_idx: usize,
    a: *const u8,
    b: *const u8,
    n: usize,
) -> Result<(), ReadError>
Record coverage information for the comparison between the n bytes of data pointed to by a, and the n bytes pointed to by b. The coverage information is written to the coverage bitmap pointed to by afl_cmp_area, starting at base_idx.

Note that if n > cmp::CMP_MAX_LEN coverage information is only collected on the first CMP_MAX_LEN bytes of the comparison.