wrap_compare_symbols

Function wrap_compare_symbols 

#[unsafe(no_mangle)]
pub extern "C" fn wrap_compare_symbols( mod_base_addr: app_pc, mod_name_ptr: *const c_char, )
Called from WinAFL. Check if any of the compare symbols (defined in the cmp::Symbols enum) are exported by the module with base address mod_base_addr. Wrap all of the compare symbols that are found with their associated wrapper function.