pub unsafe fn write_coverage(
afl_cmp_area: *mut u8,
base_idx: usize,
a: &[u8],
b: &[u8],
n: usize,
)Expand description
Record coverage information for the comparison between slices a and b. The coverage information is written to the coverage bitmap pointed to by afl_cmp_area, starting at base_idx.
Note that if n > cmp::CMP_MAX_LEN coverage information is only collected on the first
CMP_MAX_LEN bytes of the comparison.